all: autogenerated update (2019-08-05)

Update:
- cloudtasks/v2beta2
- container/v1
- dialogflow/v2
- dialogflow/v2beta1
- remotebuildexecution/v2
diff --git a/cloudtasks/v2beta2/cloudtasks-api.json b/cloudtasks/v2beta2/cloudtasks-api.json
index 1930fce..6a914ff 100644
--- a/cloudtasks/v2beta2/cloudtasks-api.json
+++ b/cloudtasks/v2beta2/cloudtasks-api.json
@@ -786,7 +786,7 @@
       }
     }
   },
-  "revision": "20190618",
+  "revision": "20190531",
   "rootUrl": "https://cloudtasks.googleapis.com/",
   "schemas": {
     "AcknowledgeTaskRequest": {
@@ -1025,7 +1025,7 @@
           "type": "string"
         },
         "leaseDuration": {
-          "description": "Required.\n\nThe duration of the lease.\n\nEach task returned in the response will\nhave its schedule_time set to the current\ntime plus the `lease_duration`. The task is leased until its\nschedule_time; thus, the task will not be\nreturned to another LeaseTasks call\nbefore its schedule_time.\n\n\nAfter the worker has successfully finished the work associated\nwith the task, the worker must call via\nAcknowledgeTask before the\nschedule_time. Otherwise the task will be\nreturned to a later LeaseTasks call so\nthat another worker can retry it.\n\nThe maximum lease duration is 1 week.\n`lease_duration` will be truncated to the nearest second.",
+          "description": "\nAfter the worker has successfully finished the work associated\nwith the task, the worker must call via\nAcknowledgeTask before the\nschedule_time. Otherwise the task will be\nreturned to a later LeaseTasks call so\nthat another worker can retry it.\n\nThe maximum lease duration is 1 week.\n`lease_duration` will be truncated to the nearest second.",
           "format": "google-duration",
           "type": "string"
         },
diff --git a/cloudtasks/v2beta2/cloudtasks-gen.go b/cloudtasks/v2beta2/cloudtasks-gen.go
index 1e6b40b..1a2f1de 100644
--- a/cloudtasks/v2beta2/cloudtasks-gen.go
+++ b/cloudtasks/v2beta2/cloudtasks-gen.go
@@ -1088,19 +1088,7 @@
 	// tag will be displayed as empty in Cloud Tasks.
 	Filter string `json:"filter,omitempty"`
 
-	// LeaseDuration: Required.
-	//
-	// The duration of the lease.
-	//
-	// Each task returned in the response will
-	// have its schedule_time set to the current
-	// time plus the `lease_duration`. The task is leased until
-	// its
-	// schedule_time; thus, the task will not be
-	// returned to another LeaseTasks call
-	// before its schedule_time.
-	//
-	//
+	// LeaseDuration:
 	// After the worker has successfully finished the work associated
 	// with the task, the worker must call via
 	// AcknowledgeTask before the
diff --git a/container/v1/container-api.json b/container/v1/container-api.json
index a85afe5..2e206ff 100644
--- a/container/v1/container-api.json
+++ b/container/v1/container-api.json
@@ -2458,7 +2458,7 @@
       }
     }
   },
-  "revision": "20190628",
+  "revision": "20190610",
   "rootUrl": "https://container.googleapis.com/",
   "schemas": {
     "AcceleratorConfig": {
@@ -2953,10 +2953,6 @@
       "description": "GetJSONWebKeysResponse is a valid JSON Web Key Set as specififed in rfc 7517",
       "id": "GetJSONWebKeysResponse",
       "properties": {
-        "cacheHeader": {
-          "$ref": "HttpCacheControlResponseHeader",
-          "description": "OnePlatform automatically extracts this field and uses it to set the HTTP\nCache-Control header."
-        },
         "keys": {
           "description": "The public component of the keys used by the cluster to sign token\nrequests.",
           "items": {
@@ -2971,10 +2967,6 @@
       "description": "GetOpenIDConfigResponse is an OIDC discovery document for the cluster.\nSee the OpenID Connect Discovery 1.0 specification for details.",
       "id": "GetOpenIDConfigResponse",
       "properties": {
-        "cacheHeader": {
-          "$ref": "HttpCacheControlResponseHeader",
-          "description": "OnePlatform automatically extracts this field and uses it to set the HTTP\nCache-Control header."
-        },
         "claims_supported": {
           "description": "Supported claims.",
           "items": {
@@ -3032,26 +3024,6 @@
       },
       "type": "object"
     },
-    "HttpCacheControlResponseHeader": {
-      "description": "RFC-2616: cache control support",
-      "id": "HttpCacheControlResponseHeader",
-      "properties": {
-        "age": {
-          "description": "14.6 response cache age, in seconds since the response is generated",
-          "format": "int64",
-          "type": "string"
-        },
-        "directive": {
-          "description": "14.9 request and response directives",
-          "type": "string"
-        },
-        "expires": {
-          "description": "14.21 response cache expires, in RFC 1123 date format",
-          "type": "string"
-        }
-      },
-      "type": "object"
-    },
     "HttpLoadBalancing": {
       "description": "Configuration options for the HTTP (L7) load balancing controller addon,\nwhich makes it easy to set up HTTP load balancers for services in a cluster.",
       "id": "HttpLoadBalancing",
diff --git a/container/v1/container-gen.go b/container/v1/container-gen.go
index b617446..7b80441 100644
--- a/container/v1/container-gen.go
+++ b/container/v1/container-gen.go
@@ -1283,11 +1283,6 @@
 // GetJSONWebKeysResponse: GetJSONWebKeysResponse is a valid JSON Web
 // Key Set as specififed in rfc 7517
 type GetJSONWebKeysResponse struct {
-	// CacheHeader: OnePlatform automatically extracts this field and uses
-	// it to set the HTTP
-	// Cache-Control header.
-	CacheHeader *HttpCacheControlResponseHeader `json:"cacheHeader,omitempty"`
-
 	// Keys: The public component of the keys used by the cluster to sign
 	// token
 	// requests.
@@ -1297,7 +1292,7 @@
 	// server.
 	googleapi.ServerResponse `json:"-"`
 
-	// ForceSendFields is a list of field names (e.g. "CacheHeader") to
+	// ForceSendFields is a list of field names (e.g. "Keys") to
 	// unconditionally include in API requests. By default, fields with
 	// empty values are omitted from API requests. However, any non-pointer,
 	// non-interface field appearing in ForceSendFields will be sent to the
@@ -1305,10 +1300,10 @@
 	// used to include empty fields in Patch requests.
 	ForceSendFields []string `json:"-"`
 
-	// NullFields is a list of field names (e.g. "CacheHeader") to include
-	// in API requests with the JSON null value. By default, fields with
-	// empty values are omitted from API requests. However, any field with
-	// an empty value appearing in NullFields will be sent to the server as
+	// NullFields is a list of field names (e.g. "Keys") to include in API
+	// requests with the JSON null value. By default, fields with empty
+	// values are omitted from API requests. However, any field with an
+	// empty value appearing in NullFields will be sent to the server as
 	// null. It is an error if a field in this list has a non-empty value.
 	// This may be used to include null fields in Patch requests.
 	NullFields []string `json:"-"`
@@ -1324,11 +1319,6 @@
 // document for the cluster.
 // See the OpenID Connect Discovery 1.0 specification for details.
 type GetOpenIDConfigResponse struct {
-	// CacheHeader: OnePlatform automatically extracts this field and uses
-	// it to set the HTTP
-	// Cache-Control header.
-	CacheHeader *HttpCacheControlResponseHeader `json:"cacheHeader,omitempty"`
-
 	// ClaimsSupported: Supported claims.
 	ClaimsSupported []string `json:"claims_supported,omitempty"`
 
@@ -1355,7 +1345,7 @@
 	// server.
 	googleapi.ServerResponse `json:"-"`
 
-	// ForceSendFields is a list of field names (e.g. "CacheHeader") to
+	// ForceSendFields is a list of field names (e.g. "ClaimsSupported") to
 	// unconditionally include in API requests. By default, fields with
 	// empty values are omitted from API requests. However, any non-pointer,
 	// non-interface field appearing in ForceSendFields will be sent to the
@@ -1363,12 +1353,13 @@
 	// used to include empty fields in Patch requests.
 	ForceSendFields []string `json:"-"`
 
-	// NullFields is a list of field names (e.g. "CacheHeader") to include
-	// in API requests with the JSON null value. By default, fields with
-	// empty values are omitted from API requests. However, any field with
-	// an empty value appearing in NullFields will be sent to the server as
-	// null. It is an error if a field in this list has a non-empty value.
-	// This may be used to include null fields in Patch requests.
+	// NullFields is a list of field names (e.g. "ClaimsSupported") to
+	// include in API requests with the JSON null value. By default, fields
+	// with empty values are omitted from API requests. However, any field
+	// with an empty value appearing in NullFields will be sent to the
+	// server as null. It is an error if a field in this list has a
+	// non-empty value. This may be used to include null fields in Patch
+	// requests.
 	NullFields []string `json:"-"`
 }
 
@@ -1414,41 +1405,6 @@
 	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
 }
 
-// HttpCacheControlResponseHeader: RFC-2616: cache control support
-type HttpCacheControlResponseHeader struct {
-	// Age: 14.6 response cache age, in seconds since the response is
-	// generated
-	Age int64 `json:"age,omitempty,string"`
-
-	// Directive: 14.9 request and response directives
-	Directive string `json:"directive,omitempty"`
-
-	// Expires: 14.21 response cache expires, in RFC 1123 date format
-	Expires string `json:"expires,omitempty"`
-
-	// ForceSendFields is a list of field names (e.g. "Age") to
-	// unconditionally include in API requests. By default, fields with
-	// empty values are omitted from API requests. However, any non-pointer,
-	// non-interface field appearing in ForceSendFields will be sent to the
-	// server regardless of whether the field is empty or not. This may be
-	// used to include empty fields in Patch requests.
-	ForceSendFields []string `json:"-"`
-
-	// NullFields is a list of field names (e.g. "Age") to include in API
-	// requests with the JSON null value. By default, fields with empty
-	// values are omitted from API requests. However, any field with an
-	// empty value appearing in NullFields will be sent to the server as
-	// null. It is an error if a field in this list has a non-empty value.
-	// This may be used to include null fields in Patch requests.
-	NullFields []string `json:"-"`
-}
-
-func (s *HttpCacheControlResponseHeader) MarshalJSON() ([]byte, error) {
-	type NoMethod HttpCacheControlResponseHeader
-	raw := NoMethod(*s)
-	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
-}
-
 // HttpLoadBalancing: Configuration options for the HTTP (L7) load
 // balancing controller addon,
 // which makes it easy to set up HTTP load balancers for services in a
diff --git a/dialogflow/v2/dialogflow-api.json b/dialogflow/v2/dialogflow-api.json
index 2ee79d8..b890ce8 100644
--- a/dialogflow/v2/dialogflow-api.json
+++ b/dialogflow/v2/dialogflow-api.json
@@ -1406,7 +1406,7 @@
       }
     }
   },
-  "revision": "20190717",
+  "revision": "20190801",
   "rootUrl": "https://dialogflow.googleapis.com/",
   "schemas": {
     "GoogleCloudDialogflowV2Agent": {
@@ -2855,7 +2855,7 @@
         },
         "intent": {
           "$ref": "GoogleCloudDialogflowV2Intent",
-          "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`."
+          "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name`, `end_interaction` and `is_fallback`."
         },
         "intentDetectionConfidence": {
           "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nThis value is for informational purpose only and is only used to\nhelp match the best intent within the classification threshold.\nThis value may change for the same end-user expression at any time due to a\nmodel retraining or change in implementation.\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.",
@@ -4470,6 +4470,41 @@
       },
       "type": "object"
     },
+    "GoogleCloudDialogflowV2beta1ModelEvaluationMetadata": {
+      "description": "The status update for performing NLU model evaluation given a dataset.\nMetadata of the returned long running operation for\nModelEvaluations.EvaluateModel.",
+      "id": "GoogleCloudDialogflowV2beta1ModelEvaluationMetadata",
+      "properties": {
+        "samplesWithIntentDetected": {
+          "description": "Optional. Number of samples that have already received the predicted\nintents from Dialogflow server.",
+          "format": "int32",
+          "type": "integer"
+        },
+        "state": {
+          "description": "Required. Represents the job that the batch worker is currently working on.",
+          "enum": [
+            "STATE_UNSPECIFIED",
+            "PARSING_DATASET",
+            "DETECTING_INTENTS",
+            "CALCULATING_METRICS",
+            "SUCCESS"
+          ],
+          "enumDescriptions": [
+            "Not specified. This value should never be used.",
+            "Parsing the customer-provided dataset in Cloud Storage, which is a CVS\nfile.",
+            "Calling the Dialogflow backend server to detect the corresponding intent\nfor each query.",
+            "Calculating the evaluation metrics for the dataset.",
+            "Job succeeded."
+          ],
+          "type": "string"
+        },
+        "totalSamples": {
+          "description": "Required. Total number of samples in the dataset.",
+          "format": "int32",
+          "type": "integer"
+        }
+      },
+      "type": "object"
+    },
     "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest": {
       "description": "Represents the contents of the original request that was passed to\nthe `[Streaming]DetectIntent` call.",
       "id": "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest",
@@ -4526,7 +4561,7 @@
         },
         "intent": {
           "$ref": "GoogleCloudDialogflowV2beta1Intent",
-          "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`."
+          "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name`, `end_interaction` and `is_fallback`."
         },
         "intentDetectionConfidence": {
           "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nThis value is for informational purpose only and is only used to\nhelp match the best intent within the classification threshold.\nThis value may change for the same end-user expression at any time due to a\nmodel retraining or change in implementation.\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.",
diff --git a/dialogflow/v2/dialogflow-gen.go b/dialogflow/v2/dialogflow-gen.go
index 9a5ffdd..a762e80 100644
--- a/dialogflow/v2/dialogflow-gen.go
+++ b/dialogflow/v2/dialogflow-gen.go
@@ -3135,7 +3135,7 @@
 	// not
 	// all fields are filled in this message, including but not limited
 	// to:
-	// `name`, `display_name` and `webhook_state`.
+	// `name`, `display_name`, `end_interaction` and `is_fallback`.
 	Intent *GoogleCloudDialogflowV2Intent `json:"intent,omitempty"`
 
 	// IntentDetectionConfidence: The intent detection confidence. Values
@@ -6493,6 +6493,62 @@
 	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
 }
 
+// GoogleCloudDialogflowV2beta1ModelEvaluationMetadata: The status
+// update for performing NLU model evaluation given a dataset.
+// Metadata of the returned long running operation
+// for
+// ModelEvaluations.EvaluateModel.
+type GoogleCloudDialogflowV2beta1ModelEvaluationMetadata struct {
+	// SamplesWithIntentDetected: Optional. Number of samples that have
+	// already received the predicted
+	// intents from Dialogflow server.
+	SamplesWithIntentDetected int64 `json:"samplesWithIntentDetected,omitempty"`
+
+	// State: Required. Represents the job that the batch worker is
+	// currently working on.
+	//
+	// Possible values:
+	//   "STATE_UNSPECIFIED" - Not specified. This value should never be
+	// used.
+	//   "PARSING_DATASET" - Parsing the customer-provided dataset in Cloud
+	// Storage, which is a CVS
+	// file.
+	//   "DETECTING_INTENTS" - Calling the Dialogflow backend server to
+	// detect the corresponding intent
+	// for each query.
+	//   "CALCULATING_METRICS" - Calculating the evaluation metrics for the
+	// dataset.
+	//   "SUCCESS" - Job succeeded.
+	State string `json:"state,omitempty"`
+
+	// TotalSamples: Required. Total number of samples in the dataset.
+	TotalSamples int64 `json:"totalSamples,omitempty"`
+
+	// ForceSendFields is a list of field names (e.g.
+	// "SamplesWithIntentDetected") to unconditionally include in API
+	// requests. By default, fields with empty values are omitted from API
+	// requests. However, any non-pointer, non-interface field appearing in
+	// ForceSendFields will be sent to the server regardless of whether the
+	// field is empty or not. This may be used to include empty fields in
+	// Patch requests.
+	ForceSendFields []string `json:"-"`
+
+	// NullFields is a list of field names (e.g.
+	// "SamplesWithIntentDetected") to include in API requests with the JSON
+	// null value. By default, fields with empty values are omitted from API
+	// requests. However, any field with an empty value appearing in
+	// NullFields will be sent to the server as null. It is an error if a
+	// field in this list has a non-empty value. This may be used to include
+	// null fields in Patch requests.
+	NullFields []string `json:"-"`
+}
+
+func (s *GoogleCloudDialogflowV2beta1ModelEvaluationMetadata) MarshalJSON() ([]byte, error) {
+	type NoMethod GoogleCloudDialogflowV2beta1ModelEvaluationMetadata
+	raw := NoMethod(*s)
+	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
+}
+
 // GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest: Represents
 // the contents of the original request that was passed to
 // the `[Streaming]DetectIntent` call.
@@ -6588,7 +6644,7 @@
 	// not
 	// all fields are filled in this message, including but not limited
 	// to:
-	// `name`, `display_name` and `webhook_state`.
+	// `name`, `display_name`, `end_interaction` and `is_fallback`.
 	Intent *GoogleCloudDialogflowV2beta1Intent `json:"intent,omitempty"`
 
 	// IntentDetectionConfidence: The intent detection confidence. Values
diff --git a/dialogflow/v2beta1/dialogflow-api.json b/dialogflow/v2beta1/dialogflow-api.json
index 1fa0e72..018eb4c 100644
--- a/dialogflow/v2beta1/dialogflow-api.json
+++ b/dialogflow/v2beta1/dialogflow-api.json
@@ -2489,7 +2489,7 @@
       }
     }
   },
-  "revision": "20190717",
+  "revision": "20190801",
   "rootUrl": "https://dialogflow.googleapis.com/",
   "schemas": {
     "GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse": {
@@ -3356,7 +3356,7 @@
         },
         "intent": {
           "$ref": "GoogleCloudDialogflowV2Intent",
-          "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`."
+          "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name`, `end_interaction` and `is_fallback`."
         },
         "intentDetectionConfidence": {
           "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nThis value is for informational purpose only and is only used to\nhelp match the best intent within the classification threshold.\nThis value may change for the same end-user expression at any time due to a\nmodel retraining or change in implementation.\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.",
@@ -4223,6 +4223,13 @@
         "singleUtterance": {
           "description": "Optional. If `false` (default), recognition does not cease until the\nclient closes the stream.\nIf `true`, the recognizer will detect a single spoken utterance in input\naudio. Recognition ceases when it detects the audio's voice has\nstopped or paused. In this case, once a detected intent is received, the\nclient should close the stream and start a new request with a new stream as\nneeded.\nNote: This setting is relevant only for streaming methods.\nNote: When specified, InputAudioConfig.single_utterance takes precedence\nover StreamingDetectIntentRequest.single_utterance.",
           "type": "boolean"
+        },
+        "speechContexts": {
+          "description": "Optional. Context information to assist speech recognition.\n\nSee [the Cloud Speech\ndocumentation](https://cloud.google.com/speech-to-text/docs/basics#phrase-hints)\nfor more details.",
+          "items": {
+            "$ref": "GoogleCloudDialogflowV2beta1SpeechContext"
+          },
+          "type": "array"
         }
       },
       "type": "object"
@@ -5414,6 +5421,41 @@
       },
       "type": "object"
     },
+    "GoogleCloudDialogflowV2beta1ModelEvaluationMetadata": {
+      "description": "The status update for performing NLU model evaluation given a dataset.\nMetadata of the returned long running operation for\nModelEvaluations.EvaluateModel.",
+      "id": "GoogleCloudDialogflowV2beta1ModelEvaluationMetadata",
+      "properties": {
+        "samplesWithIntentDetected": {
+          "description": "Optional. Number of samples that have already received the predicted\nintents from Dialogflow server.",
+          "format": "int32",
+          "type": "integer"
+        },
+        "state": {
+          "description": "Required. Represents the job that the batch worker is currently working on.",
+          "enum": [
+            "STATE_UNSPECIFIED",
+            "PARSING_DATASET",
+            "DETECTING_INTENTS",
+            "CALCULATING_METRICS",
+            "SUCCESS"
+          ],
+          "enumDescriptions": [
+            "Not specified. This value should never be used.",
+            "Parsing the customer-provided dataset in Cloud Storage, which is a CVS\nfile.",
+            "Calling the Dialogflow backend server to detect the corresponding intent\nfor each query.",
+            "Calculating the evaluation metrics for the dataset.",
+            "Job succeeded."
+          ],
+          "type": "string"
+        },
+        "totalSamples": {
+          "description": "Required. Total number of samples in the dataset.",
+          "format": "int32",
+          "type": "integer"
+        }
+      },
+      "type": "object"
+    },
     "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest": {
       "description": "Represents the contents of the original request that was passed to\nthe `[Streaming]DetectIntent` call.",
       "id": "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest",
@@ -5573,7 +5615,7 @@
         },
         "intent": {
           "$ref": "GoogleCloudDialogflowV2beta1Intent",
-          "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`."
+          "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name`, `end_interaction` and `is_fallback`."
         },
         "intentDetectionConfidence": {
           "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nThis value is for informational purpose only and is only used to\nhelp match the best intent within the classification threshold.\nThis value may change for the same end-user expression at any time due to a\nmodel retraining or change in implementation.\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.",
@@ -5742,6 +5784,25 @@
       },
       "type": "object"
     },
+    "GoogleCloudDialogflowV2beta1SpeechContext": {
+      "description": "Hints for the speech recognizer to help with recognition in a specific\nconversation state.",
+      "id": "GoogleCloudDialogflowV2beta1SpeechContext",
+      "properties": {
+        "boost": {
+          "description": "Optional. Boost for this context compared to other contexts:\n* If the boost is positive, Dialogflow will increase the probability that\n  the phrases in this context are recognized over similar sounding phrases.\n* If the boost is unspecified or non-positive, Dialogflow will not apply\n  any boost.\n\nDialogflow recommends that you use boosts in the range (0, 20] and that you\nfind a value that fits your use case with binary search.",
+          "format": "float",
+          "type": "number"
+        },
+        "phrases": {
+          "description": "Optional. A list of strings containing words and phrases that the speech\nrecognizer should recognize with higher likelihood.\n\nThis list can be used to:\n* improve accuracy for words and phrases you expect the user to say,\n  e.g. typical commands for your Dialogflow agent\n* add additional words to the speech recognizer vocabulary\n* ...\n\nSee the [Cloud Speech\ndocumentation](https://cloud.google.com/speech-to-text/quotas) for usage\nlimits.",
+          "items": {
+            "type": "string"
+          },
+          "type": "array"
+        }
+      },
+      "type": "object"
+    },
     "GoogleCloudDialogflowV2beta1SynthesizeSpeechConfig": {
       "description": "Configuration of how speech should be synthesized.",
       "id": "GoogleCloudDialogflowV2beta1SynthesizeSpeechConfig",
diff --git a/dialogflow/v2beta1/dialogflow-gen.go b/dialogflow/v2beta1/dialogflow-gen.go
index 2f65aab..28b20db 100644
--- a/dialogflow/v2beta1/dialogflow-gen.go
+++ b/dialogflow/v2beta1/dialogflow-gen.go
@@ -2022,7 +2022,7 @@
 	// not
 	// all fields are filled in this message, including but not limited
 	// to:
-	// `name`, `display_name` and `webhook_state`.
+	// `name`, `display_name`, `end_interaction` and `is_fallback`.
 	Intent *GoogleCloudDialogflowV2Intent `json:"intent,omitempty"`
 
 	// IntentDetectionConfidence: The intent detection confidence. Values
@@ -3867,6 +3867,16 @@
 	// over StreamingDetectIntentRequest.single_utterance.
 	SingleUtterance bool `json:"singleUtterance,omitempty"`
 
+	// SpeechContexts: Optional. Context information to assist speech
+	// recognition.
+	//
+	// See [the Cloud
+	// Speech
+	// documentation](https://cloud.google.com/speech-to-text/docs/bas
+	// ics#phrase-hints)
+	// for more details.
+	SpeechContexts []*GoogleCloudDialogflowV2beta1SpeechContext `json:"speechContexts,omitempty"`
+
 	// ForceSendFields is a list of field names (e.g. "AudioEncoding") to
 	// unconditionally include in API requests. By default, fields with
 	// empty values are omitted from API requests. However, any non-pointer,
@@ -6308,6 +6318,62 @@
 	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
 }
 
+// GoogleCloudDialogflowV2beta1ModelEvaluationMetadata: The status
+// update for performing NLU model evaluation given a dataset.
+// Metadata of the returned long running operation
+// for
+// ModelEvaluations.EvaluateModel.
+type GoogleCloudDialogflowV2beta1ModelEvaluationMetadata struct {
+	// SamplesWithIntentDetected: Optional. Number of samples that have
+	// already received the predicted
+	// intents from Dialogflow server.
+	SamplesWithIntentDetected int64 `json:"samplesWithIntentDetected,omitempty"`
+
+	// State: Required. Represents the job that the batch worker is
+	// currently working on.
+	//
+	// Possible values:
+	//   "STATE_UNSPECIFIED" - Not specified. This value should never be
+	// used.
+	//   "PARSING_DATASET" - Parsing the customer-provided dataset in Cloud
+	// Storage, which is a CVS
+	// file.
+	//   "DETECTING_INTENTS" - Calling the Dialogflow backend server to
+	// detect the corresponding intent
+	// for each query.
+	//   "CALCULATING_METRICS" - Calculating the evaluation metrics for the
+	// dataset.
+	//   "SUCCESS" - Job succeeded.
+	State string `json:"state,omitempty"`
+
+	// TotalSamples: Required. Total number of samples in the dataset.
+	TotalSamples int64 `json:"totalSamples,omitempty"`
+
+	// ForceSendFields is a list of field names (e.g.
+	// "SamplesWithIntentDetected") to unconditionally include in API
+	// requests. By default, fields with empty values are omitted from API
+	// requests. However, any non-pointer, non-interface field appearing in
+	// ForceSendFields will be sent to the server regardless of whether the
+	// field is empty or not. This may be used to include empty fields in
+	// Patch requests.
+	ForceSendFields []string `json:"-"`
+
+	// NullFields is a list of field names (e.g.
+	// "SamplesWithIntentDetected") to include in API requests with the JSON
+	// null value. By default, fields with empty values are omitted from API
+	// requests. However, any field with an empty value appearing in
+	// NullFields will be sent to the server as null. It is an error if a
+	// field in this list has a non-empty value. This may be used to include
+	// null fields in Patch requests.
+	NullFields []string `json:"-"`
+}
+
+func (s *GoogleCloudDialogflowV2beta1ModelEvaluationMetadata) MarshalJSON() ([]byte, error) {
+	type NoMethod GoogleCloudDialogflowV2beta1ModelEvaluationMetadata
+	raw := NoMethod(*s)
+	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
+}
+
 // GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest: Represents
 // the contents of the original request that was passed to
 // the `[Streaming]DetectIntent` call.
@@ -6581,7 +6647,7 @@
 	// not
 	// all fields are filled in this message, including but not limited
 	// to:
-	// `name`, `display_name` and `webhook_state`.
+	// `name`, `display_name`, `end_interaction` and `is_fallback`.
 	Intent *GoogleCloudDialogflowV2beta1Intent `json:"intent,omitempty"`
 
 	// IntentDetectionConfidence: The intent detection confidence. Values
@@ -7011,6 +7077,78 @@
 	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
 }
 
+// GoogleCloudDialogflowV2beta1SpeechContext: Hints for the speech
+// recognizer to help with recognition in a specific
+// conversation state.
+type GoogleCloudDialogflowV2beta1SpeechContext struct {
+	// Boost: Optional. Boost for this context compared to other contexts:
+	// * If the boost is positive, Dialogflow will increase the probability
+	// that
+	//   the phrases in this context are recognized over similar sounding
+	// phrases.
+	// * If the boost is unspecified or non-positive, Dialogflow will not
+	// apply
+	//   any boost.
+	//
+	// Dialogflow recommends that you use boosts in the range (0, 20] and
+	// that you
+	// find a value that fits your use case with binary search.
+	Boost float64 `json:"boost,omitempty"`
+
+	// Phrases: Optional. A list of strings containing words and phrases
+	// that the speech
+	// recognizer should recognize with higher likelihood.
+	//
+	// This list can be used to:
+	// * improve accuracy for words and phrases you expect the user to say,
+	//   e.g. typical commands for your Dialogflow agent
+	// * add additional words to the speech recognizer vocabulary
+	// * ...
+	//
+	// See the [Cloud
+	// Speech
+	// documentation](https://cloud.google.com/speech-to-text/quotas) for
+	// usage
+	// limits.
+	Phrases []string `json:"phrases,omitempty"`
+
+	// ForceSendFields is a list of field names (e.g. "Boost") to
+	// unconditionally include in API requests. By default, fields with
+	// empty values are omitted from API requests. However, any non-pointer,
+	// non-interface field appearing in ForceSendFields will be sent to the
+	// server regardless of whether the field is empty or not. This may be
+	// used to include empty fields in Patch requests.
+	ForceSendFields []string `json:"-"`
+
+	// NullFields is a list of field names (e.g. "Boost") to include in API
+	// requests with the JSON null value. By default, fields with empty
+	// values are omitted from API requests. However, any field with an
+	// empty value appearing in NullFields will be sent to the server as
+	// null. It is an error if a field in this list has a non-empty value.
+	// This may be used to include null fields in Patch requests.
+	NullFields []string `json:"-"`
+}
+
+func (s *GoogleCloudDialogflowV2beta1SpeechContext) MarshalJSON() ([]byte, error) {
+	type NoMethod GoogleCloudDialogflowV2beta1SpeechContext
+	raw := NoMethod(*s)
+	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
+}
+
+func (s *GoogleCloudDialogflowV2beta1SpeechContext) UnmarshalJSON(data []byte) error {
+	type NoMethod GoogleCloudDialogflowV2beta1SpeechContext
+	var s1 struct {
+		Boost gensupport.JSONFloat64 `json:"boost"`
+		*NoMethod
+	}
+	s1.NoMethod = (*NoMethod)(s)
+	if err := json.Unmarshal(data, &s1); err != nil {
+		return err
+	}
+	s.Boost = float64(s1.Boost)
+	return nil
+}
+
 // GoogleCloudDialogflowV2beta1SynthesizeSpeechConfig: Configuration of
 // how speech should be synthesized.
 type GoogleCloudDialogflowV2beta1SynthesizeSpeechConfig struct {
diff --git a/remotebuildexecution/v2/remotebuildexecution-api.json b/remotebuildexecution/v2/remotebuildexecution-api.json
index 75f90ee..b8d5728 100644
--- a/remotebuildexecution/v2/remotebuildexecution-api.json
+++ b/remotebuildexecution/v2/remotebuildexecution-api.json
@@ -446,7 +446,7 @@
       }
     }
   },
-  "revision": "20190723",
+  "revision": "20190731",
   "rootUrl": "https://remotebuildexecution.googleapis.com/",
   "schemas": {
     "BuildBazelRemoteExecutionV2Action": {
@@ -1475,6 +1475,22 @@
       },
       "type": "object"
     },
+    "GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig": {
+      "description": "AcceleratorConfig defines the accelerator cards to attach to the VM.",
+      "id": "GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig",
+      "properties": {
+        "acceleratorCount": {
+          "description": "The number of the guest accelerator cards exposed to this VM.",
+          "format": "int64",
+          "type": "string"
+        },
+        "acceleratorType": {
+          "description": "The type of accelerator to attach to this VM, e.g. \"nvidia-tesla-k80\" for\nnVidia Tesla K80.",
+          "type": "string"
+        }
+      },
+      "type": "object"
+    },
     "GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateInstanceRequest": {
       "description": "The request used for `CreateInstance`.",
       "id": "GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateInstanceRequest",
@@ -1662,6 +1678,10 @@
       "description": "Defines the configuration to be used for a creating workers in\nthe worker pool.",
       "id": "GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerConfig",
       "properties": {
+        "accelerator": {
+          "$ref": "GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig",
+          "description": "The accelerator card attached to each VM."
+        },
         "diskSizeGb": {
           "description": "Required. Size of the disk attached to the worker, in GB.\nSee https://cloud.google.com/compute/docs/disks/",
           "format": "int64",
diff --git a/remotebuildexecution/v2/remotebuildexecution-gen.go b/remotebuildexecution/v2/remotebuildexecution-gen.go
index cf11986..5385122 100644
--- a/remotebuildexecution/v2/remotebuildexecution-gen.go
+++ b/remotebuildexecution/v2/remotebuildexecution-gen.go
@@ -2597,6 +2597,42 @@
 	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
 }
 
+// GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig:
+// AcceleratorConfig defines the accelerator cards to attach to the VM.
+type GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig struct {
+	// AcceleratorCount: The number of the guest accelerator cards exposed
+	// to this VM.
+	AcceleratorCount int64 `json:"acceleratorCount,omitempty,string"`
+
+	// AcceleratorType: The type of accelerator to attach to this VM, e.g.
+	// "nvidia-tesla-k80" for
+	// nVidia Tesla K80.
+	AcceleratorType string `json:"acceleratorType,omitempty"`
+
+	// ForceSendFields is a list of field names (e.g. "AcceleratorCount") to
+	// unconditionally include in API requests. By default, fields with
+	// empty values are omitted from API requests. However, any non-pointer,
+	// non-interface field appearing in ForceSendFields will be sent to the
+	// server regardless of whether the field is empty or not. This may be
+	// used to include empty fields in Patch requests.
+	ForceSendFields []string `json:"-"`
+
+	// NullFields is a list of field names (e.g. "AcceleratorCount") to
+	// include in API requests with the JSON null value. By default, fields
+	// with empty values are omitted from API requests. However, any field
+	// with an empty value appearing in NullFields will be sent to the
+	// server as null. It is an error if a field in this list has a
+	// non-empty value. This may be used to include null fields in Patch
+	// requests.
+	NullFields []string `json:"-"`
+}
+
+func (s *GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig) MarshalJSON() ([]byte, error) {
+	type NoMethod GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig
+	raw := NoMethod(*s)
+	return gensupport.MarshalJSON(raw, s.ForceSendFields, s.NullFields)
+}
+
 // GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateInstanceRequest:
 // The request used for `CreateInstance`.
 type GoogleDevtoolsRemotebuildexecutionAdminV1alphaCreateInstanceRequest struct {
@@ -3075,6 +3111,9 @@
 // the configuration to be used for a creating workers in
 // the worker pool.
 type GoogleDevtoolsRemotebuildexecutionAdminV1alphaWorkerConfig struct {
+	// Accelerator: The accelerator card attached to each VM.
+	Accelerator *GoogleDevtoolsRemotebuildexecutionAdminV1alphaAcceleratorConfig `json:"accelerator,omitempty"`
+
 	// DiskSizeGb: Required. Size of the disk attached to the worker, in
 	// GB.
 	// See https://cloud.google.com/compute/docs/disks/
@@ -3122,7 +3161,7 @@
 	// details.
 	Reserved bool `json:"reserved,omitempty"`
 
 	// ForceSendFields is a list of field names (e.g. "DiskSizeGb") to
 	// unconditionally include in API requests. By default, fields with
 	// empty values are omitted from API requests. However, any non-pointer,
 	// non-interface field appearing in ForceSendFields will be sent to the
@@ -3130,10 +3169,10 @@
 	// used to include empty fields in Patch requests.
 	ForceSendFields []string `json:"-"`
 
 	// NullFields is a list of field names (e.g. "DiskSizeGb") to include in
 	// API requests with the JSON null value. By default, fields with empty
 	// values are omitted from API requests. However, any field with an
 	// empty value appearing in NullFields will be sent to the server as
 	// null. It is an error if a field in this list has a non-empty value.
 	// This may be used to include null fields in Patch requests.
 	NullFields []string `json:"-"`
@@ -3122,7 +3161,7 @@
 	Reserved bool `json:"reserved,omitempty"`
 
-	// ForceSendFields is a list of field names (e.g. "DiskSizeGb") to
+	// ForceSendFields is a list of field names (e.g. "Accelerator") to
 	// unconditionally include in API requests. By default, fields with
 	// empty values are omitted from API requests. However, any non-pointer,
@@ -3130,10 +3169,10 @@
 	ForceSendFields []string `json:"-"`
 
-	// NullFields is a list of field names (e.g. "DiskSizeGb") to include in
-	// API requests with the JSON null value. By default, fields with empty
-	// values are omitted from API requests. However, any field with an
-	// empty value appearing in NullFields will be sent to the server as
+	// NullFields is a list of field names (e.g. "Accelerator") to include
+	// in API requests with the JSON null value. By default, fields with
+	// empty values are omitted from API requests. However, any field with
+	// an empty value appearing in NullFields will be sent to the server as
 	// null. It is an error if a field in this list has a non-empty value.
 	// This may be used to include null fields in Patch requests.